# pycutils: Small, commonly used python functions
![PyPI - Downloads](https://img.shields.io/pypi/dm/pycutils)
![Tests](https://github.com/CangyuanLi/cutils/actions/workflows/tests.yml/badge.svg)

## What is it?

**cutils** is a collection of small but useful and widely applicable functions. Since it only uses the standard library, it is extremely lightweight and portable.

# Usage:

## Installing

The easiest way is to install **cutils** is from PyPI using pip:

```shell
pip install pycutils
```

## Running

# Usage

```python
import cutils
```
